@@ -20,9 +20,9 @@
  */
 
 #include <gnome.h>
-#include <eel/eel.h>
 
 #include "seahorse-key-store.h"
+#include "seahorse-gconf.h"
 
 enum {
 	PROP_0,
@@ -416,7 +416,8 @@ static void
 seahorse_key_store_key_removed (SeahorseKeySource *sksrc, SeahorseKey *skey, SeahorseKeyStore *skstore)
 {
     SeahorseKeyRow *skrow = (SeahorseKeyRow*)g_hash_table_lookup (skstore->priv->rows, skey);
-	seahorse_key_row_remove_all (skrow);
+    if (skrow)
+	    seahorse_key_row_remove_all (skrow);
 }
 
 /* Calls virtual |changed| for all relevant uids. adds new uids if necessary */
@@ -521,7 +522,7 @@ sort_changed(GtkTreeSortable *sort, gpointer user_data)
             t = klass->col_ids[id];
             if (t != NULL) {
                 x = g_strconcat (ord == GTK_SORT_DESCENDING ? "-" : "", t, NULL);
-                eel_gconf_set_string (klass->gconf_sort_key, x);
+                seahorse_gconf_set_string (klass->gconf_sort_key, x);
                 g_free (x);
             }
         }
@@ -529,7 +530,7 @@ sort_changed(GtkTreeSortable *sort, gpointer user_data)
     
     /* No sort so save blank */
     else {
-        eel_gconf_set_string (klass->gconf_sort_key, "");
+        seahorse_gconf_set_string (klass->gconf_sort_key, "");
     }
 }
 
@@ -581,6 +582,35 @@ check_toggled(GtkCellRendererToggle *cellrenderertoggle, gchar *path, gpointer u
     g_signal_emit_by_name (selection, "changed");    
 }
 
+static void
+row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2, 
+               SeahorseKeyStore *skstore)
+{
+    GtkTreeModel* fmodel = GTK_TREE_MODEL (skstore->priv->sort);
+    GtkTreeSelection *selection;
+    gboolean prev = FALSE;
+    GtkTreeIter iter;
+    GtkTreeIter child;
+    GValue v;
+
+    memset (&v, 0, sizeof(v));
+    g_return_if_fail (path != NULL);
+    g_return_if_fail (gtk_tree_model_get_iter (fmodel, &iter, path));
+    
+    /* We get notified in filtered coordinates, we have to convert those to base */
+    seahorse_key_store_get_base_iter (skstore, &child, &iter);
+ 
+    gtk_tree_model_get_value (GTK_TREE_MODEL (skstore), &child, KEY_STORE_CHECK, &v);
+    if(G_VALUE_TYPE (&v) == G_TYPE_BOOLEAN)
+        prev = g_value_get_boolean (&v);
+    g_value_unset (&v);    
+    
+    gtk_tree_store_set (GTK_TREE_STORE (skstore), &child, KEY_STORE_CHECK, prev ? FALSE : TRUE, -1);
+
+    selection = gtk_tree_view_get_selection (treeview);
+    g_signal_emit_by_name (selection, "changed");    
+}
+
 /* Creates a new #SeahorseKeyRow for listening to key signals */
 static void
 seahorse_key_row_add (SeahorseKeyStore *skstore, GtkTreeIter *iter, SeahorseKey *skey)
@@ -711,6 +741,7 @@ seahorse_key_store_init (SeahorseKeyStore *skstore, GtkTreeView *view)
         col = gtk_tree_view_column_new_with_attributes ("", renderer, "active", KEY_STORE_CHECK, NULL);
         gtk_tree_view_column_set_resizable (col, FALSE);
         gtk_tree_view_append_column (view, col);
+        g_signal_connect (view, "row_activated", G_CALLBACK (row_activated), skstore);
     }
     
     /* When using key pair icons, we add an icon column */
@@ -745,12 +776,13 @@ seahorse_key_store_init (SeahorseKeyStore *skstore, GtkTreeView *view)
         gtk_tree_view_append_column (view, col);
         
         gtk_tree_view_column_set_sort_column_id (col, KEY_STORE_PAIR);
-      }
-      
-	col = seahorse_key_store_append_column (view, _("Name"), KEY_STORE_NAME);
-	gtk_tree_view_column_set_sort_column_id (col, KEY_STORE_NAME);
-	
-	seahorse_key_store_append_column (view, _("Key ID"), KEY_STORE_KEYID);
+    }
+    
+    col = seahorse_key_store_append_column (view, _("Name"), KEY_STORE_NAME);
+    gtk_tree_view_column_set_sort_column_id (col, KEY_STORE_NAME);
+    
+    col = seahorse_key_store_append_column (view, _("Key ID"), KEY_STORE_KEYID);
+    gtk_tree_view_column_set_sort_column_id (col, KEY_STORE_KEYID);
 
     if (SEAHORSE_KEY_STORE_GET_CLASS (skstore)->gconf_sort_key) {
         /* Also watch for sort-changed on the store */
@@ -798,6 +830,7 @@ key_from_iterator (GtkTreeModel* model, GtkTreeIter* iter, guint *uid)
 {
     GtkTreeIter i;
     SeahorseKeyRow *skrow;
+    SeahorseKey *return_key = NULL;
     
     /* Convert to base iter if necessary */
     if (!SEAHORSE_IS_KEY_STORE (model)) {
@@ -810,8 +843,9 @@ key_from_iterator (GtkTreeModel* model, GtkTreeIter* iter, guint *uid)
     
     gtk_tree_model_get (model, iter, 
         KEY_STORE_DATA, &skrow, uid ? KEY_STORE_UID : -1, uid, -1);    
-
-   return skrow->skey;
+    if (skrow)
+        return_key = skrow->skey;
+    return return_key;
 }
 
 
@@ -870,7 +904,7 @@ seahorse_key_store_append_column (GtkTreeView *view, const gchar *label, const g
     key = SEAHORSE_KEY_STORE_GET_CLASS (skstore)->gconf_sort_key;
     
     /* Update sort order in case the sorted column was added */
-    if (key && (sort = eel_gconf_get_string (key)) != NULL) {
+    if (key && (sort = seahorse_gconf_get_string (key)) != NULL) {
         set_sort_to (skstore, sort);
         g_free (sort);
     }  
@@ -1102,4 +1136,3 @@ seahorse_key_store_get_base_iter(SeahorseKeyStore* skstore, GtkTreeIter* base_it
     gtk_tree_model_sort_convert_iter_to_child_iter (skstore->priv->sort, &i, (GtkTreeIter*)iter);
     gtk_tree_model_filter_convert_iter_to_child_iter (skstore->priv->filter, base_iter, &i);
 }
-
