@@ -21,6 +21,7 @@
 
 #include <gnome.h>
 
+#include "seahorse-gpgmex.h"
 #include "seahorse-key-op.h"
 #include "seahorse-util.h"
 #include "seahorse-key-dialogs.h"
@@ -31,6 +32,9 @@
 #define SAVE "keyedit.save.okay"
 #define YES "Y"
 
+#define PRINT(args)  if(!seahorse_util_print_fd args) return GPG_E (GPG_ERR_GENERAL)
+#define PRINTF(args) if(!seahorse_util_printf_fd args) return GPG_E (GPG_ERR_GENERAL)
+
 /**
  * seahorse_key_op_generate:
  * @sksrc: #SeahorseKeySource
@@ -55,70 +59,71 @@ seahorse_key_op_generate (SeahorseKeySource *sksrc, const gchar *name,
 			  const gchar *passphrase, const SeahorseKeyType type,
 			  const guint length, const time_t expires)
 {
-	gchar *common, *key_type, *start, *parms, *expires_date;
+    gchar *common, *key_type, *start, *parms, *expires_date = NULL;
     gpgme_error_t err;
-	gpgme_ctx_t new_ctx;
-	
-	g_return_val_if_fail (strlen (name) >= 5, GPG_E (GPG_ERR_INV_VALUE));
-	
-	/* Check lengths for each type */
-	switch (type) {
-		case DSA_ELGAMAL:
-			g_return_val_if_fail (length >= ELGAMAL_MIN && length <= LENGTH_MAX, GPG_E (GPG_ERR_INV_VALUE));
-			break;
-		case DSA:
-			g_return_val_if_fail (length >= DSA_MIN && length <= DSA_MAX, GPG_E (GPG_ERR_INV_VALUE));
-			break;
-		case RSA_SIGN:
-			g_return_val_if_fail (length >= RSA_MIN && length <= LENGTH_MAX, GPG_E (GPG_ERR_INV_VALUE));
-			break;
-		default:
-			g_return_val_if_reached (GPG_E (GPG_ERR_INV_VALUE));
-			break;
-	}
-	
-	if (expires != 0)
-		expires_date = seahorse_util_get_date_string (expires);
-	else
-		expires_date = "0";
-	
-	/* Common xml */
-	common = g_strdup_printf ("Name-Real: %s\nExpire-Date: %s\nPassphrase: %s\n"
-		"</GnupgKeyParms>", name, expires_date, passphrase);
-	if (email != NULL && strlen (email) > 0)
-		common = g_strdup_printf ("Name-Email: %s\n%s", email, common);
-	if (comment != NULL && strlen (comment) > 0)
-		common = g_strdup_printf ("Name-Comment: %s\n%s", comment, common);
-	
-	if (type == RSA_SIGN)
-		key_type = "Key-Type: RSA";
-	else
-		key_type = "Key-Type: DSA";
-	
-	start = g_strdup_printf ("<GnupgKeyParms format=\"internal\">\n%s\nKey-Length: ", key_type);
-	
-	/* Subkey xml */
-	if (type == DSA_ELGAMAL)
-		parms = g_strdup_printf ("%s%d\nSubkey-Type: ELG-E\nSubkey-Length: %d\n%s",
-					 start, DSA_MAX, length, common);
-	else
-		parms = g_strdup_printf ("%s%d\n%s", start, length, common);
+    gpgme_ctx_t new_ctx;
+    
+    g_return_val_if_fail (strlen (name) >= 5, GPG_E (GPG_ERR_INV_VALUE));
+    
+    /* Check lengths for each type */
+    switch (type) {
+    case DSA_ELGAMAL:
+        g_return_val_if_fail (length >= ELGAMAL_MIN && length <= LENGTH_MAX, GPG_E (GPG_ERR_INV_VALUE));
+        break;
+    case DSA:
+        g_return_val_if_fail (length >= DSA_MIN && length <= DSA_MAX, GPG_E (GPG_ERR_INV_VALUE));
+        break;
+    case RSA_SIGN:
+        g_return_val_if_fail (length >= RSA_MIN && length <= LENGTH_MAX, GPG_E (GPG_ERR_INV_VALUE));
+        break;
+    default:
+        g_return_val_if_reached (GPG_E (GPG_ERR_INV_VALUE));
+        break;
+    }
+    
+    if (expires != 0)
+        expires_date = seahorse_util_get_date_string (expires);
+    if (!expires_date)
+        expires_date = g_strdup ("0");
+    
+    /* Common xml */
+    common = g_strdup_printf ("Name-Real: %s\nExpire-Date: %s\nPassphrase: %s\n"
+                              "</GnupgKeyParms>", name, expires_date, passphrase);
+    if (email != NULL && strlen (email) > 0)
+        common = g_strdup_printf ("Name-Email: %s\n%s", email, common);
+    if (comment != NULL && strlen (comment) > 0)
+        common = g_strdup_printf ("Name-Comment: %s\n%s", comment, common);
+    
+    if (type == RSA_SIGN)
+        key_type = "Key-Type: RSA";
+    else
+        key_type = "Key-Type: DSA";
+    
+    start = g_strdup_printf ("<GnupgKeyParms format=\"internal\">\n%s\nKey-Length: ", key_type);
+    
+    /* Subkey xml */
+    if (type == DSA_ELGAMAL)
+        parms = g_strdup_printf ("%s%d\nSubkey-Type: ELG-E\nSubkey-Length: %d\n%s",
+                                 start, DSA_MAX, length, common);
+    else
+        parms = g_strdup_printf ("%s%d\n%s", start, length, common);
 
     new_ctx = seahorse_key_source_new_context (sksrc);	
     g_return_val_if_fail (new_ctx != NULL, GPG_E (GPG_ERR_GENERAL));
     
-	err = gpgme_op_genkey (new_ctx, parms, NULL, NULL);
+    err = gpgme_op_genkey (new_ctx, parms, NULL, NULL);
     gpgme_release (new_ctx);
-	
-	if (GPG_IS_OK (err))
-        seahorse_key_source_refresh (sksrc, FALSE);
-	
-	/* Free xmls */
-	g_free (parms);
-	g_free (start);
-	g_free (common);
-	
-	return err;
+    
+    if (GPG_IS_OK (err))
+        seahorse_key_source_refresh_async (sksrc, SEAHORSE_KEY_SOURCE_NEW);
+    
+    /* Free xmls */
+    g_free (parms);
+    g_free (start);
+    g_free (common);
+    g_free (expires_date);
+    
+    return err;
 }
 
 /* helper function for deleting @skey */
@@ -249,10 +254,10 @@ edit_key (SeahorseKey *skey, SeahorseEditParm *parms, SeahorseKeyChange change)
 	/* do edit callback, release data */
 	err = gpgme_op_edit (sksrc->ctx, skey->key, seahorse_key_op_edit, parms, out);
 	gpgme_data_release (out);
-	g_return_val_if_fail (GPG_IS_OK (err), err);
+
 	/* signal key */
-	seahorse_key_changed (skey, change);
-	seahorse_key_source_show_progress (sksrc, _("Operation complete"), -1);
+	if(GPG_IS_OK (err))
+		seahorse_key_changed (skey, change);
 	return err;
 }
 
@@ -285,29 +290,29 @@ sign_action (guint state, gpointer data, int fd)
 	switch (state) {
 		/* select uid */
 		case SIGN_UID:
-            seahorse_util_printf_fd (fd, "uid %d", parm->index);
+            PRINTF ((fd, "uid %d", parm->index));
 			break;
 		case SIGN_COMMAND:
-            seahorse_util_print_fd (fd, parm->command);
+            PRINT ((fd, parm->command));
 			break;
 		/* if expires */
 		case SIGN_EXPIRE:
-            seahorse_util_print_fd (fd, (parm->expire) ? YES : "N");
+            PRINT ((fd, (parm->expire) ? YES : "N"));
 			break;
 		case SIGN_CONFIRM:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		case SIGN_CHECK:
-            seahorse_util_printf_fd (fd, "%d", parm->check);
+            PRINTF ((fd, "%d", parm->check));
 			break;
 		case SIGN_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -341,6 +346,8 @@ sign_transit (guint current_state, gpgme_status_code_t status,
 			/* if doing all uids, confirm */
 			if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "keyedit.sign_all.okay"))
 				next_state = SIGN_CONFIRM;
+			else if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "sign_uid.okay"))
+			    next_state = SIGN_CONFIRM;
 			/* need to do expires */
 			else if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.expire"))
 				next_state = SIGN_EXPIRE;
@@ -370,6 +377,8 @@ sign_transit (guint current_state, gpgme_status_code_t status,
 			/* need to do check */
 			if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.class"))
 				next_state = SIGN_CHECK;
+			else if (status == GPGME_STATUS_GET_BOOL && g_str_equal (args, "sign_uid.okay"))
+			    next_state = SIGN_CONFIRM;
 			/* need to do expire */
 			else if (status == GPGME_STATUS_GET_LINE && g_str_equal (args, "sign_uid.expire"))
 				next_state = SIGN_EXPIRE;
@@ -419,6 +428,7 @@ sign_transit (guint current_state, gpgme_status_code_t status,
 /**
  * seahorse_key_op_sign:
  * @skey: #SeahorseKey to sign
+ * @signer: #SeahorseKeyPair to sign with
  * @index: User ID to sign, 0 is all user IDs
  * @check: #SeahorseSignCheck
  * @options: #SeahorseSignOptions
@@ -428,32 +438,40 @@ sign_transit (guint current_state, gpgme_status_code_t status,
  * Returns: Error value
  **/
 gpgme_error_t
-seahorse_key_op_sign (SeahorseKey *skey, const guint index,
-		              SeahorseSignCheck check, SeahorseSignOptions options)
+seahorse_key_op_sign (SeahorseKey *skey, SeahorseKeyPair *skpair, const guint index,
+                      SeahorseSignCheck check, SeahorseSignOptions options)
 {
-	SignParm *sign_parm;
-	SeahorseEditParm *parms;
+    SignParm *sign_parm;
+    SeahorseEditParm *parms;
+    SeahorseKeySource *sksrc;
     gpgme_error_t err;
-	
-	g_return_val_if_fail (SEAHORSE_IS_KEY (skey), GPG_E (GPG_ERR_WRONG_KEY_USAGE));
-	g_return_val_if_fail (index <= seahorse_key_get_num_uids (skey), GPG_E (GPG_ERR_INV_VALUE));
-	
-	sign_parm = g_new (SignParm, 1);
-	sign_parm->index = index;
-	sign_parm->expire = ((options & SIGN_EXPIRES) != 0);
-	sign_parm->check = check;
-	sign_parm->command = "sign";
-	
-	/* if sign is local */
-	if ((options & SIGN_LOCAL) != 0)
-		sign_parm->command = g_strdup_printf ("l%s", sign_parm->command);
-	/* if sign is non-revocable */
-	if ((options & SIGN_NO_REVOKE) != 0)
-		sign_parm->command = g_strdup_printf ("nr%s", sign_parm->command);
-	
-	parms = seahorse_edit_parm_new (SIGN_START, sign_action, sign_transit, sign_parm);
-	
-	err =  edit_key (skey, parms, SKEY_CHANGE_SIGNERS);
+
+    g_return_val_if_fail (SEAHORSE_IS_KEY (skey), GPG_E (GPG_ERR_WRONG_KEY_USAGE));
+    g_return_val_if_fail (index <= seahorse_key_get_num_uids (skey), GPG_E (GPG_ERR_INV_VALUE));
+
+    sign_parm = g_new (SignParm, 1);
+    sign_parm->index = index;
+    sign_parm->expire = ((options & SIGN_EXPIRES) != 0);
+    sign_parm->check = check;
+    
+    sign_parm->command = g_strdup_printf ("%s%ssign", 
+                                (options & SIGN_NO_REVOKE) ? "nr" : "",
+                                (options & SIGN_LOCAL) ? "l" : "");
+    
+    sksrc = seahorse_key_get_source (skey);
+    g_return_val_if_fail (sksrc != NULL, GPG_E (GPG_ERR_INV_VALUE));
+    
+    gpgme_signers_clear (sksrc->ctx);
+    if (skpair) {
+        err = gpgme_signers_add (sksrc->ctx, skpair->secret);
+        if (!GPG_IS_OK (err))
+            return err;
+    }
+    
+    parms = seahorse_edit_parm_new (SIGN_START, sign_action, sign_transit, sign_parm);
+    
+    err =  edit_key (skey, parms, SKEY_CHANGE_SIGNERS);
+    g_free (sign_parm->command);
  
     /* If it was already signed then it's not an error */
     if (!GPG_IS_OK (err) && gpgme_err_code (err) == GPG_ERR_EALREADY)
@@ -477,22 +495,22 @@ edit_pass_action (guint state, gpointer data, int fd)
 {
 	switch (state) {
 		case PASS_COMMAND:
-            seahorse_util_print_fd (fd, "passwd");
+            PRINT ((fd, "passwd"));
 			break;
         case PASS_PASSPHRASE:
             /* Do nothing */
             return GPG_OK;
 		case PASS_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		case PASS_SAVE:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -599,25 +617,25 @@ edit_trust_action (guint state, gpointer data, int fd)
 	switch (state) {
 		/* enter command */
 		case TRUST_COMMAND:
-            seahorse_util_print_fd (fd, "trust");
+            PRINT ((fd, "trust"));
 			break;
 		/* enter numeric trust value */
 		case TRUST_VALUE:
-            seahorse_util_printf_fd (fd, "%d", trust);
+            PRINTF ((fd, "%d", trust));
 			break;
 		/* confirm ultimate or if save */
 		case TRUST_CONFIRM:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		/* quit */
 		case TRUST_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -738,16 +756,16 @@ edit_disable_action (guint state, gpointer data, int fd)
 	
 	switch (state) {
 		case DISABLE_COMMAND:
-            seahorse_util_print_fd (fd, command);
+            PRINT ((fd, command));
 			break;
 		case DISABLE_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			break;
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -843,25 +861,27 @@ static gpgme_error_t
 edit_expire_action (guint state, gpointer data, int fd)
 {
 	ExpireParm *parm = (ExpireParm*)data;
-  
+    gchar *exp;
+    
 	switch (state) {
 		/* selected key */
 		case EXPIRE_SELECT:
-            seahorse_util_printf_fd (fd, "key %d", parm->index);
+            PRINTF ((fd, "key %d", parm->index));
 			break;
 		case EXPIRE_COMMAND:
-            seahorse_util_print_fd (fd, "expire");
+            PRINT ((fd, "expire"));
 			break;
 		/* set date */
 		case EXPIRE_DATE:
-            seahorse_util_print_fd (fd, (parm->expires) ?
-				seahorse_util_get_date_string (parm->expires) : "0");
+            exp = seahorse_util_get_date_string (parm->expires);
+            PRINT ((fd, exp ? exp : "0"));
+            g_free (exp);
 			break;
 		case EXPIRE_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		case EXPIRE_SAVE:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		case EXPIRE_ERROR:
 			break;
@@ -869,7 +889,7 @@ edit_expire_action (guint state, gpointer data, int fd)
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -993,23 +1013,23 @@ add_revoker_action (guint state, gpointer data, int fd)
 	
 	switch (state) {
 		case ADD_REVOKER_COMMAND:
-            seahorse_util_print_fd (fd, "addrevoker");
+            PRINT ((fd, "addrevoker"));
 			break;
 		/* select revoker */
 		case ADD_REVOKER_SELECT:
-            seahorse_util_print_fd (fd, keyid);
+            PRINT ((fd, keyid));
 			break;
 		case ADD_REVOKER_CONFIRM:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		case ADD_REVOKER_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -1130,28 +1150,28 @@ add_uid_action (guint state, gpointer data, int fd)
 	
 	switch (state) {
 		case ADD_UID_COMMAND:
-            seahorse_util_print_fd (fd, "adduid");
+            PRINT ((fd, "adduid"));
 			break;
 		case ADD_UID_NAME:
-            seahorse_util_print_fd (fd, parm->name);
+            PRINT ((fd, parm->name));
 			break;
 		case ADD_UID_EMAIL:
-            seahorse_util_print_fd (fd, parm->email);
+            PRINT ((fd, parm->email));
 			break;
 		case ADD_UID_COMMENT:
-            seahorse_util_print_fd (fd, parm->comment);
+            PRINT ((fd, parm->comment));
 			break;
 		case ADD_UID_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		case ADD_UID_SAVE:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -1282,33 +1302,35 @@ static gpgme_error_t
 add_key_action (guint state, gpointer data, int fd)
 {
 	SubkeyParm *parm = (SubkeyParm*)data;
-	
+	gchar *exp;
+    
 	switch (state) {
 		case ADD_KEY_COMMAND:
-            seahorse_util_print_fd (fd, "addkey");
+            PRINT ((fd, "addkey"));
 			break;
 		case ADD_KEY_TYPE:
-            seahorse_util_printf_fd (fd, "%d", parm->type);
+            PRINTF ((fd, "%d", parm->type));
 			break;
 		case ADD_KEY_LENGTH:
-            seahorse_util_printf_fd (fd, "%d", parm->length);
+            PRINTF ((fd, "%d", parm->length));
 			break;
 		/* Get exact date or 0 */
 		case ADD_KEY_EXPIRES:
-            seahorse_util_print_fd (fd, (parm->expires) ?
-				seahorse_util_get_date_string (parm->expires) : "0");
-			break;
+            exp = seahorse_util_get_date_string (parm->expires);
+            PRINT ((fd, exp ? exp : "0"));
+            g_free (exp);
+            break;
 		case ADD_KEY_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		case ADD_KEY_SAVE:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -1447,22 +1469,22 @@ del_key_action (guint state, gpointer data, int fd)
 	switch (state) {
 		/* select key */
 		case DEL_KEY_SELECT:
-            seahorse_util_printf_fd (fd, "key %d", (guint)data);
+            PRINTF ((fd, "key %d", (guint)data));
 			break;
 		case DEL_KEY_COMMAND:
-            seahorse_util_print_fd (fd, "delkey");
+            PRINT ((fd, "delkey"));
 			break;
 		case DEL_KEY_CONFIRM:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		case DEL_KEY_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			return GPG_E (GPG_ERR_GENERAL);
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -1584,32 +1606,32 @@ rev_subkey_action (guint state, gpointer data, int fd)
 	
 	switch (state) {
 		case REV_SUBKEY_SELECT:
-            seahorse_util_printf_fd (fd, "key %d", parm->index);
+            PRINTF ((fd, "key %d", parm->index));
 			break;
 		case REV_SUBKEY_COMMAND:
-            seahorse_util_print_fd (fd, "revkey");
+            PRINT ((fd, "revkey"));
 			break;
 		case REV_SUBKEY_CONFIRM:
-            seahorse_util_print_fd (fd, YES);
+            PRINT ((fd, YES));
 			break;
 		case REV_SUBKEY_REASON:
-            seahorse_util_printf_fd (fd, "%d", parm->reason);
+            PRINTF ((fd, "%d", parm->reason));
 			break;
 		case REV_SUBKEY_DESCRIPTION:
-            seahorse_util_printf_fd (fd, "%s\n", parm->description);
+            PRINTF ((fd, "%s\n", parm->description));
 			break;
 		/* Need empty line */
 		case REV_SUBKEY_ENDDESC:
-            seahorse_util_print_fd (fd, "\n");
+            PRINT ((fd, "\n"));
 			break;
 		case REV_SUBKEY_QUIT:
-            seahorse_util_print_fd (fd, QUIT);
+            PRINT ((fd, QUIT));
 			break;
 		default:
 			g_return_val_if_reached (GPG_E (GPG_ERR_GENERAL));
 	}
 	
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
 	return GPG_OK;
 }
 
@@ -1769,23 +1791,23 @@ primary_action (guint state, gpointer data, int fd)
     switch (state) {
     case PRIMARY_SELECT:
         /* Note that the GPG id is not 0 based */
-        seahorse_util_printf_fd (fd, "uid %d", parm->index);
+        PRINTF ((fd, "uid %d", parm->index));
         break;
     case PRIMARY_COMMAND:
-        seahorse_util_print_fd (fd, "primary");
+        PRINT ((fd, "primary"));
         break;
     case PRIMARY_QUIT:
-        seahorse_util_print_fd (fd, QUIT);
+        PRINT ((fd, QUIT));
         break;
     case PRIMARY_SAVE:
-        seahorse_util_print_fd (fd, YES);
+        PRINT ((fd, YES));
         break;
     default:
         g_return_val_if_reached (GPG_E (GPG_ERR_GENERAL));
         break;
     }
   
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
     return GPG_OK;
 }
 
@@ -1904,26 +1926,26 @@ del_uid_action (guint state, gpointer data, int fd)
     
     switch (state) {
     case DEL_UID_SELECT:
-        seahorse_util_printf_fd (fd, "uid %d", parm->index);
+        PRINTF ((fd, "uid %d", parm->index));
         break;
     case DEL_UID_COMMAND:
-        seahorse_util_print_fd (fd, "deluid");
+        PRINT ((fd, "deluid"));
         break;
     case DEL_UID_CONFIRM:
-        seahorse_util_print_fd (fd, YES);
+        PRINT ((fd, YES));
         break;
     case DEL_UID_QUIT:
-        seahorse_util_print_fd (fd, QUIT);
+        PRINT ((fd, QUIT));
         break;
     case DEL_UID_SAVE:
-        seahorse_util_print_fd (fd, YES);
+        PRINT ((fd, YES));
         break;
     default:
         g_return_val_if_reached (GPG_E (GPG_ERR_GENERAL));
         break;
     }
   
-    seahorse_util_print_fd (fd, "\n");
+    PRINT ((fd, "\n"));
     return GPG_OK;
 }
 
